.. _nicmosdata:

*******************
NICMOS ImageObjects
*******************

.. currentmodule:: drizzlepac.nicmosData

.. autoclass:: NICMOSInputImage
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: NIC1InputImage
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: NIC2InputImage
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: NIC3InputImage
   :members:
   :undoc-members:
   :show-inheritance:
